]> ruderich.org/simon Gitweb - config/dotfiles.git/blobdiff - setup.sh
setup.sh: always symlink ~/.xsession
[config/dotfiles.git] / setup.sh
index 368fa0b7b07b4a1e0ea1559fa7704f966a762af1..45fda4d984c7d42585f0eaaf2226229a089d2dab 100755 (executable)
--- a/setup.sh
+++ b/setup.sh
@@ -2,7 +2,7 @@
 
 # Setup script for X11 configuration files.
 
-# Copyright (C) 2011-2012  Simon Ruderich
+# Copyright (C) 2011-2014  Simon Ruderich
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-set -e
+set -eu
 
 . ../lib.sh
 
@@ -52,21 +52,19 @@ if installed X; then
          }'
     # Xresources uses ! as comment instead of #.
     sed_i 's/^#/!/' Xresources
-    # Use urxvt's pseudo-transparency if compton is not available. Better than
-    # nothing.
-    if ! installed compton; then
+    # Use urxvt's pseudo-transparency if neither compton nor xcompmgr are
+    # available. Better than nothing.
+    if ! installed compton && ! installed xcompmgr; then
         echo 'Xresources: no compton found, enabling pseudo-transparency'
-        sed_i 's/^Rxvt\*background/!&/' Xresources
+        sed_i 's/^Rxvt\*background: \[/!&/' Xresources
         sed_i 's/^!NO_COMPTON //' Xresources
     fi
 
     if test ! "x`os`" = xdarwin; then
         link xinitrc ~/.xinitrc
-        # lightdm doesn't use ~/.xinitrc but ~/.xprofile instead. Assume it's
-        # used when the lightdm configuration file is present.
-        if test -f "$HOME/.dmrc"; then
-            link xinitrc ~/.xprofile
-        fi
+        # Most display managers use ~/.xsession instead of ~/.xinitrc (which
+        # is used by e.g. startx). Provide both links.
+        link xinitrc ~/.xsession
     fi
     if test -f xinitrc.local; then
         link xinitrc.local ~/.xinitrc.local
@@ -76,6 +74,10 @@ if installed X; then
     link XCompose ~/.XCompose
 fi
 
+if installed xscreensaver; then
+    link xscreensaver ~/.xscreensaver
+fi
+
 if installed xpdf; then
     link xpdfrc ~/.xpdfrc
 fi